==> fd-faq-900.0-noarch-1.txz: usr/share/doc/fd-faq/misc.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# Miscellaneous known issues
#  

This page documents all the known issues that does not fit into other categories. Some of the issues have workarounds to make it work, some don't.



-   **1.** Guvcview crash when attempting to capture video.

**Cause**: portaudio library (used by guvcview) has incompatibilities with recent version of ALSA libraries included in Fatdog64 800.

**Workaround**: Before capturing video, click the "Audio Controls" tab and change the "Input Device" from **default**, or **sysdefault** to something else.  
-   **2.** ROX crashes often. At the time or writing, have unexplained ROX crash on certain systems using radeon hardware.

**Cause:** Unknown, possible various reasons.

**Workaround:** Open terminal, and re-launch ROX, using the following commands (note: case is important, type them as you see them here):


    killall -9 ROX-Filer

rox-desktop


-   **3.** Printing problem. My printer requires the vendor driver, and with great difficulty I have installed it. But it still does not print.

**Cause:** There are a great many reasons why it fails to work.

**Workaround:** Your best bet is to jump to the [Puppy Linux forum](http://oldforum.puppylinux.com/puppy) and ask there. But before you do that, one of the possible cases is that your printer driver requires **ghostscript**. So fire up the package manager, and install **ghostscript**; and try printing again. Most of the time you don't even need to reboot. If that still fails, report the the Puppy Linux forum as above (and keep ghostscript installed, *do not uninstall* it again).  
-   **4.** Sometimes, on certain systems (and on certain video adapters), after closing VLC (the media player), the VLC icon stays on the panel and cannot be removed, killed. The only way to remove it is by doing a hard-kill on it ("**killall -9 vlc**"). This is a known issue (see: [https:`//forum.manjaro.org/t/zombie-vlc-processes/51744`](https://forum.manjaro.org/t/zombie-vlc-processes/51744)), but it can be avoided by going into VLC's preference settings and change the **Video Output** preferences from "**Auto**" to "**Xvideo output (XCB)**" or closing VLC using **CTRL+q** shortcut.

**Note:** as of version **3.0.13** it has been fixed upstream.





----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [misc.html](https://distro.ibiblio.org/fatdog/web/faqs/misc.html) on 2023-09-08._

==> fd-faq-901.0-noarch-1.txz: usr/share/doc/fd-faq/misc.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# Miscellaneous known issues
#  

This page documents all the known issues that does not fit into other categories. Some of the issues have workarounds to make it work, some don't.



-   **1.** Guvcview crash when attempting to capture video.

**Cause**: portaudio library (used by guvcview) has incompatibilities with recent version of ALSA libraries included in Fatdog64 800.

**Workaround**: Before capturing video, click the "Audio Controls" tab and change the "Input Device" from **default**, or **sysdefault** to something else.  
-   **2.** ROX crashes often. At the time or writing, have unexplained ROX crash on certain systems using radeon hardware.

**Cause:** Unknown, possible various reasons.

**Workaround:** Open terminal, and re-launch ROX, using the following commands (note: case is important, type them as you see them here):


    killall -9 ROX-Filer

rox-desktop


-   **3.** Printing problem. My printer requires the vendor driver, and with great difficulty I have installed it. But it still does not print.

**Cause:** There are a great many reasons why it fails to work.

**Workaround:** Your best bet is to jump to the [Puppy Linux forum](http://oldforum.puppylinux.com/puppy) and ask there. But before you do that, one of the possible cases is that your printer driver requires **ghostscript**. So fire up the package manager, and install **ghostscript**; and try printing again. Most of the time you don't even need to reboot. If that still fails, report the the Puppy Linux forum as above (and keep ghostscript installed, *do not uninstall* it again).  
-   **4.** Sometimes, on certain systems (and on certain video adapters), after closing VLC (the media player), the VLC icon stays on the panel and cannot be removed, killed. The only way to remove it is by doing a hard-kill on it ("**killall -9 vlc**"). This is a known issue (see: <https://forum.manjaro.org/t/zombie-vlc-processes/51744>), but it can be avoided by going into VLC's preference settings and change the **Video Output** preferences from "**Auto**" to "**Xvideo output (XCB)**" or closing VLC using **CTRL+q** shortcut.

**Note:** as of version **3.0.13** it has been fixed upstream.





----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [misc.html](https://distro.ibiblio.org/fatdog/web/faqs/misc.html) on 2023-10-09._
